from mod_pywebsocket import common, msgutil


def web_socket_do_extra_handshake(request):
    if request.ws_requested_extensions is not None:
        for extension_request in request.ws_requested_extensions:
            if extension_request.name() == "permessage-deflate":
                raise ValueError("permessage-deflate should not be offered")


def web_socket_transfer_data(request):
    while True:
        rcvd = msgutil.receive_message(request)
        opcode = request.ws_stream.get_last_received_opcode()
        if opcode == common.OPCODE_BINARY:
            msgutil.send_message(request, rcvd, binary=True)
        elif opcode == common.OPCODE_TEXT:
            msgutil.send_message(request, rcvd)



from mod_pywebsocket import msgutil


def web_socket_do_extra_handshake(request):
    pass


def web_socket_transfer_data(request):
    resp = "Test"
    if msgutil.receive_message(request) == "data":
        resp = "Hello world!"
    msgutil.send_message(request, resp)



from mod_pywebsocket import common, msgutil


def web_socket_do_extra_handshake(request):
    deflate_removed = False

    if request.ws_extension_processors is not None:
        for extension_processor in request.ws_extension_processors:
            if extension_processor.name() == "deflate":
                request.ws_extension_processors.remove(extension_processor)
                deflate_removed = True

    if deflate_removed is False:
        raise ValueError("deflate extension processor not found")


def web_socket_transfer_data(request):
    while True:
        rcvd = msgutil.receive_message(request)
        opcode = request.ws_stream.get_last_received_opcode()
        if opcode == common.OPCODE_BINARY:
            msgutil.send_message(request, rcvd, binary=True)
        elif opcode == common.OPCODE_TEXT:
            msgutil.send_message(request, rcvd)
